@@ -17,7 +17,7 @@ from ax.core.generator_run import GeneratorRun
 from ax.core.metric import Metric
 from ax.core.runner import Runner
 from ax.core.types import TCandidateMetadata
-from ax.utils.common.equality import Base
+from ax.utils.common.base import Base
 from ax.utils.common.typeutils import not_none
 
 
@@ -295,7 +295,7 @@ class BaseTrial(ABC, Base):
     @immutable_once_run
     def trial_type(self, trial_type: Optional[str]) -> None:
         """Identifier used to distinguish trial types in experiments
-           with multiple trial types.
+        with multiple trial types.
         """
         if self._experiment is not None:
             if not self._experiment.supports_trial_type(trial_type):
