@@ -13,9 +13,10 @@ from typing import Dict, Iterable, Optional, Set, Type
 import numpy as np
 import pandas as pd
 from ax.core.types import TFidelityTrialEvaluation, TTrialEvaluation
-from ax.utils.common.equality import Base
+from ax.utils.common.base import Base
 
 
+# pyre-fixme[16]: Module `pd` has no attribute `Timestamp`.
 TPdTimestamp = pd.Timestamp
 
 COLUMN_DATA_TYPES = {
@@ -52,7 +53,10 @@ class Data(Base):
     """
 
     def __init__(
-        self, df: Optional[pd.DataFrame] = None, description: Optional[str] = None
+        self,
+        # pyre-fixme[11]: Annotation `DataFrame` is not defined as a type.
+        df: Optional[pd.DataFrame] = None,
+        description: Optional[str] = None,
     ) -> None:
         """Init Data.
 
@@ -63,6 +67,7 @@ class Data(Base):
         """
         # Initialize with barebones DF.
         if df is None:
+            # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
             self._df = pd.DataFrame(columns=self.required_columns())
         else:
             columns = set(df.columns)
@@ -118,11 +123,46 @@ class Data(Base):
         return COLUMN_DATA_TYPES
 
     @staticmethod
-    def from_multiple_data(data: Iterable[Data]) -> Data:
+    def from_multiple_data(
+        data: Iterable[Data], subset_metrics: Optional[Iterable[str]] = None
+    ) -> Data:
+        """Combines multiple data objects into one (with the concatenated
+        underlying dataframe).
+
+        NOTE: if one or more data objects in the iterable is of a custom
+        subclass of `Data`, object of that class will be returned. If
+        the iterable contains multiple types of `Data`, an error will be
+        raised.
+
+        Args:
+            data: Iterable of Ax `Data` objects to combine.
+            subset_metrics: If specified, combined `Data` will only contain
+                metrics, names of which appear in this iterable,
+                in the underlying dataframe.
+        """
         dfs = [datum.df for datum in data]
+
         if len(dfs) == 0:
             return Data()
-        return Data(df=pd.concat(dfs, axis=0, sort=True))
+
+        if subset_metrics:
+            dfs = [df.loc[df["metric_name"].isin(subset_metrics)] for df in dfs]
+
+        # obtain type of first elt in iterable (we know it's not empty)
+        data_type = type(data[0])
+
+        # check if all types in iterable match the first type
+        if all((type(datum) is data_type) for datum in data):
+            # if all types in iterable are subclasses of Data, return the subclass
+            if issubclass(data_type, Data):
+                # pyre-fixme[16]: Module `pd` has no attribute `concat`.
+                return data_type(df=pd.concat(dfs, axis=0, sort=True))
+            else:
+                # if not, return the original Data object
+                # pyre-fixme[16]: Module `pd` has no attribute `concat`.
+                return Data(df=pd.concat(dfs, axis=0, sort=True))
+        else:
+            raise ValueError("More than one custom data type found in data iterable")
 
     @staticmethod
     def from_evaluations(
@@ -165,6 +205,7 @@ class Data(Base):
         if sample_sizes:
             for record in records:
                 record["n"] = sample_sizes[str(record["arm_name"])]
+        # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
         return Data(df=pd.DataFrame(records))
 
     @staticmethod
@@ -211,6 +252,7 @@ class Data(Base):
         if sample_sizes:
             for record in records:
                 record["n"] = sample_sizes[str(record["arm_name"])]
+        # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
         return Data(df=pd.DataFrame(records))
 
     @property
@@ -232,7 +274,14 @@ class Data(Base):
             str: The hash of the DataFrame.
 
         """
-        return md5(self.df.to_json().encode("utf-8")).hexdigest()  # pyre-ignore
+        return md5(self.df.to_json().encode("utf-8")).hexdigest()
+
+    @property
+    def metric_names(self) -> Set[str]:
+        """Set of metric names that appear in the underlying dataframe of
+        this `Data` object.
+        """
+        return set() if self.df.empty else set(self.df["metric_name"].values)
 
 
 def set_single_trial(data: Data) -> Data:
