@@ -16,9 +16,9 @@ from ax.core.arm import Arm
 from ax.core.data import Data
 from ax.core.experiment import Experiment
 from ax.core.types import TCandidateMetadata, TParameterization
+from ax.utils.common.base import Base
 from ax.utils.common.constants import Keys
-from ax.utils.common.equality import Base
-from ax.utils.common.timeutils import current_timestamp_in_millis
+from ax.utils.common.typeutils import not_none
 
 
 OBS_COLS = {
@@ -197,7 +197,11 @@ class Observation(Base):
 
 
 def _observations_from_dataframe(
-    experiment: Experiment, df: pd.DataFrame, cols: List[str], arm_name_only: bool
+    experiment: Experiment,
+    # pyre-fixme[11]: Annotation `DataFrame` is not defined as a type.
+    df: pd.DataFrame,
+    cols: List[str],
+    arm_name_only: bool,
 ) -> List[Observation]:
     """Helper method for extracting observations grouped by `cols` from `df`."""
     observations = []
@@ -223,8 +227,11 @@ def _observations_from_dataframe(
         if trial_index is not None:
             trial = experiment.trials[trial_index]
             metadata = trial._get_candidate_metadata(arm_name) or {}
-            if Keys.OBS_FROM_DF_TIMESTAMP not in metadata:
-                metadata[Keys.OBS_FROM_DF_TIMESTAMP] = current_timestamp_in_millis()
+            if Keys.TRIAL_COMPLETION_TIMESTAMP not in metadata:
+                if trial._time_completed is not None:
+                    metadata[Keys.TRIAL_COMPLETION_TIMESTAMP] = not_none(
+                        trial._time_completed
+                    ).timestamp()
             obs_kwargs[Keys.METADATA] = metadata
         observations.append(
             Observation(
