@@ -9,7 +9,7 @@ from enum import Enum
 from typing import Dict, List, Optional, Type, Union
 
 from ax.core.types import TParamValue
-from ax.utils.common.equality import Base
+from ax.utils.common.base import Base
 
 
 FIXED_CHOICE_PARAM_ERROR = (
@@ -202,8 +202,7 @@ class RangeParameter(Parameter):
 
     @property
     def log_scale(self) -> bool:
-        """Whether to sample in log space when drawing random values of the parameter.
-        """
+        """Whether the parameter's random values should be sampled from log space."""
         return self._log_scale
 
     def update_range(
@@ -272,7 +271,7 @@ class RangeParameter(Parameter):
 
     def is_valid_type(self, value: TParamValue) -> bool:
         """Same as default except allows floats whose value is an int
-           for Int parameters.
+        for Int parameters.
         """
         if not (isinstance(value, float) or isinstance(value, int)):
             return False
