@@ -7,22 +7,37 @@
 from typing import Any, Callable, Dict, List, Optional, Set, Tuple
 
 import numpy as np
-from ax.core.objective import MultiObjective, Objective, ScalarizedObjective
+import torch
 from ax.core.observation import ObservationData, ObservationFeatures
-from ax.core.optimization_config import OptimizationConfig
-from ax.core.outcome_constraint import ComparisonOp, OutcomeConstraint
+from ax.core.optimization_config import (
+    MultiObjectiveOptimizationConfig,
+    OptimizationConfig,
+    TRefPoint,
+)
 from ax.core.search_space import SearchSpace
-from ax.core.types import TBounds, TCandidateMetadata, TConfig, TGenMetadata
+from ax.core.types import TCandidateMetadata, TConfig, TGenMetadata
 from ax.modelbridge.base import ModelBridge
 from ax.modelbridge.modelbridge_utils import (
+    extract_objective_thresholds,
+    extract_objective_weights,
+    extract_outcome_constraints,
     extract_parameter_constraints,
     get_bounds_and_task,
     get_fixed_features,
     parse_observation_features,
     pending_observations_as_array,
     transform_callback,
+    validate_and_apply_final_transform,
 )
-from ax.utils.common.typeutils import not_none
+from ax.models.torch.frontier_utils import (
+    TFrontierEvaluator,
+    get_default_frontier_evaluator,
+    get_weighted_mc_objective_and_objective_thresholds,
+)
+from ax.utils.common.docutils import copy_doc
+from ax.utils.common.typeutils import checked_cast_optional, not_none
+from botorch.utils.multi_objective.hypervolume import Hypervolume
+from torch import Tensor
 
 
 FIT_MODEL_ERROR = "Model must be fit before {action}."
@@ -97,8 +112,7 @@ class ArrayModelBridge(ModelBridge):
         fidelity_features: List[int],
         candidate_metadata: Optional[List[List[TCandidateMetadata]]],
     ) -> None:
-        """Fit the model, given numpy types.
-        """
+        """Fit the model, given numpy types."""
         self.model = model
         self.model.fit(
             Xs=Xs,
@@ -146,12 +160,8 @@ class ArrayModelBridge(ModelBridge):
     def _predict(
         self, observation_features: List[ObservationFeatures]
     ) -> List[ObservationData]:
-        # Convert observations to array
-        f, cov = self._model_predict(
-            X=self._transform_observation_features(
-                observation_features=observation_features
-            )
-        )
+        X = observation_features_to_array(self.parameters, observation_features)
+        f, cov = self._model_predict(X=X)
         # Convert arrays to observations
         return array_to_observation_data(f=f, cov=cov, outcomes=self.outcomes)
 
@@ -160,6 +170,11 @@ class ArrayModelBridge(ModelBridge):
     ) -> Tuple[np.ndarray, np.ndarray]:  # pragma: no cover
         return self.model.predict(X=X)
 
+    def _get_extra_model_gen_kwargs(
+        self, optimization_config: OptimizationConfig
+    ) -> Dict[str, Any]:
+        return {}
+
     def _gen(
         self,
         n: int,
@@ -205,6 +220,9 @@ class ArrayModelBridge(ModelBridge):
             outcome_constraints=optimization_config.outcome_constraints,
             outcomes=self.outcomes,
         )
+        extra_model_gen_kwargs = self._get_extra_model_gen_kwargs(
+            optimization_config=optimization_config
+        )
         linear_constraints = extract_parameter_constraints(
             search_space.parameter_constraints, self.parameters
         )
@@ -224,6 +242,7 @@ class ArrayModelBridge(ModelBridge):
             model_gen_options=model_gen_options,
             rounding_func=transform_callback(self.parameters, self.transforms),
             target_fidelities=target_fidelities,
+            **extra_model_gen_kwargs,
         )
         # Transform array to observations
         observation_features = parse_observation_features(
@@ -343,11 +362,8 @@ class ArrayModelBridge(ModelBridge):
     def _evaluate_acquisition_function(
         self, observation_features: List[ObservationFeatures]
     ) -> List[float]:
-        return self._model_evaluate_acquisition_function(
-            X=self._transform_observation_features(
-                observation_features=observation_features
-            )
-        ).tolist()
+        X = observation_features_to_array(self.parameters, observation_features)
+        return self._model_evaluate_acquisition_function(X=X).tolist()
 
     def _model_evaluate_acquisition_function(self, X: np.ndarray) -> np.ndarray:
         raise NotImplementedError  # pragma: no cover
@@ -388,12 +404,26 @@ class ArrayModelBridge(ModelBridge):
         importances_arr = importances_dict[metric_name].flatten()
         return dict(zip(self.parameters, importances_arr))
 
+    def _transform_observation_data(
+        self, observation_data: List[ObservationData]
+    ) -> Any:  # TODO(jej): Make return type parametric
+        """Apply terminal transform to given observation data and return result.
+
+        Converts a set of observation data to a tuple of
+            - an (n x m) array of means
+            - an (n x m x m) array of covariances
+        """
+        try:
+            return observation_data_to_array(observation_data=observation_data)
+        except (KeyError, TypeError):  # pragma: no cover
+            raise ValueError("Invalid formatting of observation data.")
+
     def _transform_observation_features(
         self, observation_features: List[ObservationFeatures]
-    ) -> Any:
-        """Apply terminal transform to given observation features and return result.
+    ) -> Any:  # TODO(jej): Make return type parametric
+        """Apply terminal transform to given observation features and return result
+        as an N x D array of points.
         """
-        """Converts a set of observation features to a nxd array of points."""
         try:
             return np.array(
                 [
@@ -406,6 +436,215 @@ class ArrayModelBridge(ModelBridge):
         except (KeyError, TypeError):  # pragma: no cover
             raise ValueError("Invalid formatting of observation features.")
 
+    @copy_doc(ModelBridge._pareto_frontier)
+    # pyre-fixme[14]: `_pareto_frontier` overrides method defined in `ModelBridge`
+    #  inconsistently.
+    def _pareto_frontier(
+        self,
+        objective_thresholds: Optional[TRefPoint] = None,
+        observation_features: Optional[List[ObservationFeatures]] = None,
+        observation_data: Optional[List[ObservationData]] = None,
+        optimization_config: Optional[MultiObjectiveOptimizationConfig] = None,
+    ) -> List[ObservationData]:
+        # TODO(jej): This method should be refactored to move tensor
+        # conversions into a separate utility, and eventually should be
+        # moved into base.py.
+        # The reason this method is currently implemented in array.py is to
+        # allow the broadest possible set of models to call frontier and
+        # hypervolume evaluation functions given the current API.
+        X = (
+            self.transform_observation_features(observation_features)
+            if observation_features
+            else None
+        )
+        X = self._array_to_tensor(X) if X is not None else None
+        Y, Yvar = (None, None)
+        if observation_data:
+            Y, Yvar = self.transform_observation_data(observation_data)
+        if Y is not None and Yvar is not None:
+            Y, Yvar = (self._array_to_tensor(Y), self._array_to_tensor(Yvar))
+
+        # Optimization_config
+        mooc = optimization_config or checked_cast_optional(
+            MultiObjectiveOptimizationConfig, self._optimization_config
+        )
+        if not mooc:
+            raise ValueError(
+                (
+                    "experiment must have an existing optimization_config "
+                    "of type MultiObjectiveOptimizationConfig "
+                    "or `optimization_config` must be passed as an argument."
+                )
+            )
+        if not isinstance(mooc, MultiObjectiveOptimizationConfig):
+            mooc = not_none(MultiObjectiveOptimizationConfig.from_opt_conf(mooc))
+        if objective_thresholds:
+            mooc = mooc.clone_with_args(objective_thresholds=objective_thresholds)
+
+        optimization_config = mooc
+
+        # Transform OptimizationConfig.
+        optimization_config = self.transform_optimization_config(
+            optimization_config=optimization_config,
+            fixed_features=ObservationFeatures(parameters={}),
+        )
+        # Extract weights, constraints, and objective_thresholds
+        objective_weights = extract_objective_weights(
+            objective=optimization_config.objective, outcomes=self.outcomes
+        )
+        outcome_constraints = extract_outcome_constraints(
+            outcome_constraints=optimization_config.outcome_constraints,
+            outcomes=self.outcomes,
+        )
+        objective_thresholds_arr = extract_objective_thresholds(
+            objective_thresholds=optimization_config.objective_thresholds,
+            outcomes=self.outcomes,
+        )
+        # Transform to tensors.
+        obj_w, oc_c, _, _ = validate_and_apply_final_transform(
+            objective_weights=objective_weights,
+            outcome_constraints=outcome_constraints,
+            linear_constraints=None,
+            pending_observations=None,
+            final_transform=self._array_to_tensor,
+        )
+        obj_t = self._array_to_tensor(objective_thresholds_arr)
+        frontier_evaluator = self._get_frontier_evaluator()
+        # pyre-ignore[28]: Unexpected keyword `model` to anonymous call
+        f, cov = frontier_evaluator(
+            model=self.model,
+            X=X,
+            Y=Y,
+            Yvar=Yvar,
+            objective_thresholds=obj_t,
+            objective_weights=obj_w,
+            outcome_constraints=oc_c,
+        )
+        f, cov = f.detach().cpu().clone().numpy(), cov.detach().cpu().clone().numpy()
+        frontier_observation_data = array_to_observation_data(
+            f=f, cov=cov, outcomes=not_none(self.outcomes)
+        )
+        # Untransform observations
+        for t in reversed(self.transforms.values()):  # noqa T484
+            frontier_observation_data = t.untransform_observation_data(
+                frontier_observation_data, []
+            )
+        return frontier_observation_data
+
+    @copy_doc(ModelBridge.predicted_pareto_frontier)
+    def predicted_pareto_frontier(
+        self,
+        objective_thresholds: Optional[TRefPoint] = None,
+        observation_features: Optional[List[ObservationFeatures]] = None,
+        optimization_config: Optional[OptimizationConfig] = None,
+    ) -> List[ObservationData]:
+        # If observation_features is not provided, use model training features.
+        observation_features = (
+            observation_features
+            if observation_features is not None
+            else [obs.features for obs in self.get_training_data()]
+        )
+        if not observation_features:
+            raise ValueError(
+                "Must receive observation_features as input or the model must "
+                "have training data."
+            )
+
+        return self._pareto_frontier(
+            objective_thresholds=objective_thresholds,
+            observation_features=observation_features,
+            # pyre-fixme[6]: Expected `Optional[MultiObjectiveOptimizationConfig]`
+            #  for 3rd param but got `Optional[OptimizationConfig]`.
+            optimization_config=optimization_config,
+        )
+
+    @copy_doc(ModelBridge._hypervolume)
+    def _hypervolume(
+        self,
+        objective_thresholds: Optional[TRefPoint] = None,
+        observation_features: Optional[List[ObservationFeatures]] = None,
+        observation_data: Optional[List[ObservationData]] = None,
+        optimization_config: Optional[OptimizationConfig] = None,
+    ) -> float:
+        # Extract a tensor of outcome means from observation data.
+        observation_data = self._pareto_frontier(
+            objective_thresholds=objective_thresholds,
+            observation_features=observation_features,
+            observation_data=observation_data,
+            # pyre-fixme[6]: Expected `Optional[MultiObjectiveOptimizationConfig]`
+            #  for 4th param but got `Optional[OptimizationConfig]`.
+            optimization_config=optimization_config,
+        )
+        if not observation_data:
+            # The hypervolume of an empty set is always 0.
+            return 0
+        means, _ = self._transform_observation_data(observation_data)
+
+        # Extract objective_weights and objective_thresholds
+        if optimization_config is None:
+            optimization_config = (
+                # pyre-fixme[16]: `Optional` has no attribute `clone`.
+                self._optimization_config.clone()
+                if self._optimization_config is not None
+                else None
+            )
+        else:
+            optimization_config = optimization_config.clone()
+
+        if objective_thresholds is not None:
+            optimization_config = optimization_config.clone_with_args(
+                objective_thresholds=objective_thresholds
+            )
+
+        obj_w = extract_objective_weights(
+            objective=optimization_config.objective, outcomes=self.outcomes
+        )
+        obj_w = self._array_to_tensor(obj_w)  # TODO: can I get rid of these tensors?
+        objective_thresholds_arr = extract_objective_thresholds(
+            objective_thresholds=optimization_config.objective_thresholds,
+            outcomes=self.outcomes,
+        )
+        obj_t = self._array_to_tensor(
+            objective_thresholds_arr
+        )  # TODO: can I get rid of these tensors?
+        obj, obj_t = get_weighted_mc_objective_and_objective_thresholds(
+            objective_weights=obj_w, objective_thresholds=obj_t
+        )
+        means = obj(means)
+        hv = Hypervolume(ref_point=obj_t)
+        return hv.compute(means)
+
+    @copy_doc(ModelBridge.predicted_hypervolume)
+    def predicted_hypervolume(
+        self,
+        objective_thresholds: Optional[TRefPoint] = None,
+        observation_features: Optional[List[ObservationFeatures]] = None,
+        optimization_config: Optional[OptimizationConfig] = None,
+    ) -> float:
+        # If observation_features is not provided, use model training features.
+        observation_features = (
+            observation_features
+            if observation_features is not None
+            else [obs.features for obs in self.get_training_data()]
+        )
+        if not observation_features:
+            raise ValueError(
+                "Must receive observation_features as input or the model must "
+                "have training data."
+            )
+
+        return self._hypervolume(
+            objective_thresholds=objective_thresholds,
+            observation_features=observation_features,
+            optimization_config=optimization_config,
+        )
+
+    def _get_frontier_evaluator(self) -> TFrontierEvaluator:
+        return get_default_frontier_evaluator()
+
+    def _array_to_tensor(self, array: np.ndarray) -> Tensor:
+        return torch.tensor(array)
+
 
 def array_to_observation_data(
     f: np.ndarray, cov: np.ndarray, outcomes: List[str]
@@ -413,8 +652,8 @@ def array_to_observation_data(
     """Convert arrays of model predictions to a list of ObservationData.
 
     Args:
-        f: An (n x d) array
-        cov: An (n x d x d) array
+        f: An (n x m) array
+        cov: An (n x m x m) array
         outcomes: A list of d outcome names
 
     Returns: A list of n ObservationData
@@ -431,6 +670,31 @@ def array_to_observation_data(
     return observation_data
 
 
+def observation_data_to_array(
+    observation_data: List[ObservationData],
+) -> Tuple[np.ndarray, np.ndarray]:
+    """Convert a list of Observation data to arrays.
+
+    Args:
+        observation_data: A list of n ObservationData
+
+    Returns:
+        An array of n ObservationData, each containing
+            - f: An (n x m) array
+            - cov: An (n x m x m) array
+    """
+    means = np.array([obsd.means for obsd in observation_data])
+    covs = np.array([obsd.covariance for obsd in observation_data])
+    return means, covs
+
+
+def observation_features_to_array(
+    parameters: List[str], obsf: List[ObservationFeatures]
+) -> np.ndarray:
+    """Convert a list of Observation features to arrays."""
+    return np.array([[of.parameters[p] for p in parameters] for of in obsf])
+
+
 def _convert_observations(
     observation_data: List[ObservationData],
     observation_features: List[ObservationFeatures],
@@ -482,60 +746,6 @@ def _convert_observations(
     return Xs_array, Ys_array, Yvars_array, candidate_metadata
 
 
-def extract_objective_weights(objective: Objective, outcomes: List[str]) -> np.ndarray:
-    """Extract a weights for objectives.
-
-    Weights are for a maximization problem.
-
-    Give an objective weight to each modeled outcome. Outcomes that are modeled
-    but not part of the objective get weight 0.
-
-    In the single metric case, the objective is given either +/- 1, depending
-    on the minimize flag.
-
-    In the multiple metric case, each objective is given the input weight,
-    multiplied by the minimize flag.
-
-    Args:
-        objective: Objective to extract weights from.
-        outcomes: n-length list of names of metrics.
-
-    Returns:
-        (n,) array of weights.
-
-    """
-    s = -1.0 if objective.minimize else 1.0
-    objective_weights = np.zeros(len(outcomes))
-    if isinstance(objective, ScalarizedObjective):
-        for obj_metric, obj_weight in objective.metric_weights:
-            objective_weights[outcomes.index(obj_metric.name)] = obj_weight * s
-    elif isinstance(objective, MultiObjective):
-        for obj_metric, obj_weight in objective.metric_weights:
-            # Rely on previously extracted lower_is_better weights not objective.
-            objective_weights[outcomes.index(obj_metric.name)] = obj_weight or s
-    else:
-        objective_weights[outcomes.index(objective.metric.name)] = s
-    return objective_weights
-
-
-def extract_outcome_constraints(
-    outcome_constraints: List[OutcomeConstraint], outcomes: List[str]
-) -> TBounds:
-    # Extract outcome constraints
-    if len(outcome_constraints) > 0:
-        A = np.zeros((len(outcome_constraints), len(outcomes)))
-        b = np.zeros((len(outcome_constraints), 1))
-        for i, c in enumerate(outcome_constraints):
-            s = 1 if c.op == ComparisonOp.LEQ else -1
-            j = outcomes.index(c.metric.name)
-            A[i, j] = s
-            b[i, 0] = s * c.bound
-        outcome_constraint_bounds: TBounds = (A, b)
-    else:
-        outcome_constraint_bounds = None
-    return outcome_constraint_bounds
-
-
 def validate_optimization_config(
     optimization_config: OptimizationConfig, outcomes: List[str]
 ) -> None:
