@@ -68,6 +68,13 @@ class TestGenerationStrategy(TestCase):
         )
         self.mock_in_registry = self.registry_setup_dict_patcher.start()
 
+        # model bridges are mocked, which makes kwargs' validation difficult,
+        # so for now we will skip it in the generation strategy tests.
+        # NOTE: Starting with Python3.8 this is not a problem as `autospec=True`
+        # ensures that the mocks have correct signatures, but in earlier
+        # versions kwarg validation on mocks does not really work.
+        self.step_model_kwargs = {"silently_filter_kwargs": True}
+
     def tearDown(self):
         self.torch_model_bridge_patcher.stop()
         self.discrete_model_bridge_patcher.stop()
@@ -230,8 +237,14 @@ class TestGenerationStrategy(TestCase):
         sobol_GPEI = GenerationStrategy(
             name="Sobol+GPEI",
             steps=[
-                GenerationStep(model=Models.SOBOL, num_trials=5),
-                GenerationStep(model=Models.GPEI, num_trials=2),
+                GenerationStep(
+                    model=Models.SOBOL,
+                    num_trials=5,
+                    model_kwargs=self.step_model_kwargs,
+                ),
+                GenerationStep(
+                    model=Models.GPEI, num_trials=2, model_kwargs=self.step_model_kwargs
+                ),
             ],
         )
         self.assertEqual(sobol_GPEI.name, "Sobol+GPEI")
@@ -240,6 +253,7 @@ class TestGenerationStrategy(TestCase):
         for i in range(7):
             g = sobol_GPEI.gen(exp)
             exp.new_trial(generator_run=g).run()
+            self.assertEqual(len(sobol_GPEI._generator_runs), i + 1)
             if i > 4:
                 self.mock_torch_model_bridge.assert_called()
             else:
@@ -274,8 +288,16 @@ class TestGenerationStrategy(TestCase):
         exp = get_branin_experiment()
         sobol_GPEI_generation_strategy = GenerationStrategy(
             steps=[
-                GenerationStep(model=Models.SOBOL, num_trials=5),
-                GenerationStep(model=Models.GPEI, num_trials=-1),
+                GenerationStep(
+                    model=Models.SOBOL,
+                    num_trials=5,
+                    model_kwargs=self.step_model_kwargs,
+                ),
+                GenerationStep(
+                    model=Models.GPEI,
+                    num_trials=-1,
+                    model_kwargs=self.step_model_kwargs,
+                ),
             ]
         )
         self.assertEqual(sobol_GPEI_generation_strategy.name, "Sobol+GPEI")
@@ -289,13 +311,38 @@ class TestGenerationStrategy(TestCase):
                     sobol_GPEI_generation_strategy.model, TorchModelBridge
                 )
 
+    def test_sobol_strategy(self):
+        exp = get_branin_experiment()
+        sobol_generation_strategy = GenerationStrategy(
+            steps=[
+                GenerationStep(
+                    model=Models.SOBOL,
+                    num_trials=5,
+                    max_parallelism=10,
+                    use_update=False,
+                    enforce_num_trials=False,
+                )
+            ]
+        )
+        for i in range(1, 6):
+            sobol_generation_strategy.gen(exp, n=1)
+            self.assertEqual(len(sobol_generation_strategy._generator_runs), i)
+
     @patch(f"{Experiment.__module__}.Experiment.fetch_data", return_value=get_data())
     def test_factorial_thompson_strategy(self, _):
         exp = get_branin_experiment()
         factorial_thompson_generation_strategy = GenerationStrategy(
             steps=[
-                GenerationStep(model=Models.FACTORIAL, num_trials=1),
-                GenerationStep(model=Models.THOMPSON, num_trials=-1),
+                GenerationStep(
+                    model=Models.FACTORIAL,
+                    num_trials=1,
+                    model_kwargs=self.step_model_kwargs,
+                ),
+                GenerationStep(
+                    model=Models.THOMPSON,
+                    num_trials=-1,
+                    model_kwargs=self.step_model_kwargs,
+                ),
             ]
         )
         self.assertEqual(
@@ -349,8 +396,14 @@ class TestGenerationStrategy(TestCase):
         sobol_GPEI_generation_strategy = GenerationStrategy(
             name="Sobol+GPEI",
             steps=[
-                GenerationStep(model=Models.SOBOL, num_trials=1),
-                GenerationStep(model=Models.GPEI, num_trials=6),
+                GenerationStep(
+                    model=Models.SOBOL,
+                    num_trials=1,
+                    model_kwargs=self.step_model_kwargs,
+                ),
+                GenerationStep(
+                    model=Models.GPEI, num_trials=6, model_kwargs=self.step_model_kwargs
+                ),
             ],
         )
         self.assertEqual(sobol_GPEI_generation_strategy.name, "Sobol+GPEI")
