@@ -4,7 +4,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Callable, Dict, List, Optional, Tuple, Type
+from typing import Callable, Dict, List, Optional, Tuple, Type, Union
 
 import numpy as np
 import torch
@@ -15,6 +15,7 @@ from ax.core.optimization_config import OptimizationConfig
 from ax.core.search_space import SearchSpace
 from ax.core.types import TCandidateMetadata, TConfig, TGenMetadata
 from ax.modelbridge.array import FIT_MODEL_ERROR, ArrayModelBridge
+from ax.modelbridge.modelbridge_utils import validate_and_apply_final_transform
 from ax.modelbridge.transforms.base import Transform
 from ax.models.torch_base import TorchModel
 from ax.utils.common.typeutils import not_none
@@ -39,12 +40,6 @@ class TorchModelBridge(ArrayModelBridge):
     """
 
     model: Optional[TorchModel]
-    # pyre-fixme[15]: `outcomes` overrides attribute defined in `ArrayModelBridge`
-    #  inconsistently.
-    outcomes: Optional[List[str]]
-    # pyre-fixme[15]: `parameters` overrides attribute defined in `ArrayModelBridge`
-    #  inconsistently.
-    parameters: Optional[List[str]]
     _default_model_gen_options: TConfig
 
     def __init__(
@@ -186,11 +181,12 @@ class TorchModelBridge(ArrayModelBridge):
     ) -> Tuple[np.ndarray, np.ndarray, TGenMetadata, List[TCandidateMetadata]]:
         if not self.model:  # pragma: no cover
             raise ValueError(FIT_MODEL_ERROR.format(action="_model_gen"))
-        obj_w, oc_c, l_c, pend_obs = self._validate_and_convert_to_tensors(
+        obj_w, oc_c, l_c, pend_obs = validate_and_apply_final_transform(
             objective_weights=objective_weights,
             outcome_constraints=outcome_constraints,
             linear_constraints=linear_constraints,
             pending_observations=pending_observations,
+            final_transform=self._array_to_tensor,
         )
         tensor_rounding_func = self._array_callable_to_tensor_callable(rounding_func)
         augmented_model_gen_options = {
@@ -229,11 +225,12 @@ class TorchModelBridge(ArrayModelBridge):
     ) -> Optional[np.ndarray]:  # pragma: no cover
         if not self.model:  # pragma: no cover
             raise ValueError(FIT_MODEL_ERROR.format(action="_model_gen"))
-        obj_w, oc_c, l_c, _ = self._validate_and_convert_to_tensors(
+        obj_w, oc_c, l_c, _ = validate_and_apply_final_transform(
             objective_weights=objective_weights,
             outcome_constraints=outcome_constraints,
             linear_constraints=linear_constraints,
             pending_observations=None,
+            final_transform=self._array_to_tensor,
         )
         try:
             # pyre-fixme[16]: `Optional` has no attribute `best_point`.
@@ -273,41 +270,7 @@ class TorchModelBridge(ArrayModelBridge):
             cov_test.detach().cpu().clone().numpy(),
         )
 
-    def _validate_and_convert_to_tensors(
-        self,
-        objective_weights: np.ndarray,
-        outcome_constraints: Optional[Tuple[np.ndarray, np.ndarray]],
-        linear_constraints: Optional[Tuple[np.ndarray, np.ndarray]],
-        pending_observations: Optional[List[np.ndarray]],
-    ) -> Tuple[
-        Tensor,
-        Optional[Tuple[Tensor, Tensor]],
-        Optional[Tuple[Tensor, Tensor]],
-        Optional[List[Tensor]],
-    ]:
-        objective_weights: Tensor = self._array_to_tensor(objective_weights)
-        if outcome_constraints is not None:  # pragma: no cover
-            outcome_constraints: Tuple[Tensor, Tensor] = (
-                self._array_to_tensor(outcome_constraints[0]),
-                self._array_to_tensor(outcome_constraints[1]),
-            )
-        if linear_constraints is not None:  # pragma: no cover
-            linear_constraints: Tuple[Tensor, Tensor] = (
-                self._array_to_tensor(linear_constraints[0]),
-                self._array_to_tensor(linear_constraints[1]),
-            )
-        if pending_observations is not None:  # pragma: no cover
-            pending_observations: List[Tensor] = self._array_list_to_tensors(
-                pending_observations
-            )
-        return (
-            objective_weights,
-            outcome_constraints,
-            linear_constraints,
-            pending_observations,
-        )
-
-    def _array_to_tensor(self, array: np.ndarray) -> Tensor:
+    def _array_to_tensor(self, array: Union[np.ndarray, List[float]]) -> Tensor:
         return torch.tensor(array, dtype=self.dtype, device=self.device)
 
     def _array_list_to_tensors(self, arrays: List[np.ndarray]) -> List[Tensor]:
@@ -327,3 +290,9 @@ class TorchModelBridge(ArrayModelBridge):
         return self._array_to_tensor(
             super()._transform_observation_features(observation_features)
         )
+
+    def _transform_observation_data(
+        self, observation_data: List[ObservationData]
+    ) -> Tuple[Tensor, Tensor]:
+        mean, cov = super()._transform_observation_data(observation_data)
+        return self._array_to_tensor(mean), self._array_to_tensor(cov)
