@@ -10,7 +10,11 @@ import numpy as np
 from ax.core.types import TCandidateMetadata
 from ax.models.numpy_base import NumpyModel
 from ax.utils.common.docutils import copy_doc
+
+# pyre-fixme[21]: Could not find module `sklearn.ensemble`.
 from sklearn.ensemble import RandomForestRegressor
+
+# pyre-fixme[21]: Could not find module `sklearn.tree`.
 from sklearn.tree import DecisionTreeRegressor
 
 
@@ -34,10 +38,9 @@ class RandomForest(NumpyModel):
     ) -> None:
         self.max_features = max_features
         self.num_trees = num_trees
+        # pyre-fixme[11]: Annotation `RandomForestRegressor` is not defined as a type.
         self.models: List[RandomForestRegressor] = []
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `Xs` expected.
     @copy_doc(NumpyModel.fit)
     def fit(
         self,
@@ -62,14 +65,10 @@ class RandomForest(NumpyModel):
                 )
             )
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `X` expected.
     @copy_doc(NumpyModel.predict)
     def predict(self, X: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
         return _rf_predict(self.models, X)
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `X_test` expected.
     @copy_doc(NumpyModel.cross_validate)
     def cross_validate(
         self,
@@ -110,6 +109,7 @@ def _get_rf(
 
     Returns: Fitted Random Forest.
     """
+    # pyre-fixme[16]: Module `sklearn` has no attribute `ensemble`.
     r = RandomForestRegressor(
         n_estimators=num_trees, max_features=max_features, bootstrap=True
     )
@@ -136,7 +136,7 @@ def _rf_predict(
     f = np.zeros((X.shape[0], len(models)))
     cov = np.zeros((X.shape[0], len(models), len(models)))
     for i, m in enumerate(models):
-        preds = np.vstack([tree.predict(X) for tree in m.estimators_])  # pyre-ignore
+        preds = np.vstack([tree.predict(X) for tree in m.estimators_])
         f[:, i] = preds.mean(0)
         cov[:, i, i] = preds.var(0)
     return f, cov
