@@ -34,6 +34,8 @@ from gpytorch.kernels.kernel import Kernel
 from gpytorch.kernels.rbf_kernel import postprocess_rbf
 from gpytorch.kernels.scale_kernel import ScaleKernel
 from gpytorch.mlls.exact_marginal_log_likelihood import ExactMarginalLogLikelihood
+
+# pyre-fixme[21]: Could not find module `scipy.optimize`.
 from scipy.optimize import approx_fprime
 from torch import Tensor
 
@@ -413,7 +415,9 @@ def extract_map_statedict(
         else:
             model_idx = 0
             param_name = k
-        map_sds[model_idx][param_name] = torch.select(v, 0, 0)
+        if len(v.shape) > 1:
+            v = torch.select(v, 0, 0)
+        map_sds[model_idx][param_name] = v
     return map_sds
 
 
@@ -487,7 +491,13 @@ def alebo_acqf_optimizer(
     """
     candidate_list, acq_value_list = [], []
     candidates = torch.tensor([], device=B.device, dtype=B.dtype)
-    base_X_pending = acq_function.X_pending  # pyre-ignore
+    try:
+        base_X_pending = acq_function.X_pending  # pyre-ignore
+        acq_has_X_pend = True
+    except AttributeError:
+        base_X_pending = None
+        acq_has_X_pend = False
+        assert n == 1
     for i in range(n):
         # Generate initial points for optimization inside embedding
         m_init = ALEBOInitializer(B.cpu().numpy(), nsamp=10 * raw_samples)
@@ -516,13 +526,15 @@ def alebo_acqf_optimizer(
             candidate_list.append(candidate)
             acq_value_list.append(acq_value)
             candidates = torch.cat(candidate_list, dim=-2)
-            acq_function.set_X_pending(
-                torch.cat([base_X_pending, candidates], dim=-2)
-                if base_X_pending is not None
-                else candidates
-            )
+            if acq_has_X_pend:
+                acq_function.set_X_pending(
+                    torch.cat([base_X_pending, candidates], dim=-2)
+                    if base_X_pending is not None
+                    else candidates
+                )
         logger.info(f"Generated sequential candidate {i+1} of {n}")
-    acq_function.set_X_pending(base_X_pending)
+    if acq_has_X_pend:
+        acq_function.set_X_pending(base_X_pending)
     return candidates, torch.stack(acq_value_list)
 
 
@@ -558,8 +570,6 @@ class ALEBO(BotorchModel):
             acqf_optimizer=alebo_acqf_optimizer,
         )
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `Xs` expected.
     @copy_doc(TorchModel.fit)
     def fit(
         self,
@@ -585,16 +595,12 @@ class ALEBO(BotorchModel):
         self.dtype = self.B.dtype
         self.model = self.get_and_fit_model(Xs=self.Xs, Ys=self.Ys, Yvars=self.Yvars)
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `X` expected.
     @copy_doc(TorchModel.predict)
     def predict(self, X: Tensor) -> Tuple[Tensor, Tensor]:
         Xd = (self.B @ X.t()).t()  # Project down
         with gpytorch.settings.max_cholesky_size(2000):
             return super().predict(X=Xd)
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `bounds` expected.
     @copy_doc(TorchModel.best_point)
     def best_point(
         self,
@@ -671,8 +677,6 @@ class ALEBO(BotorchModel):
         #  Dict[str, typing.Any], None]`.
         return Xopt, w, {}, None
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `Xs` expected.
     @copy_doc(TorchModel.update)
     def update(
         self,
@@ -698,8 +702,6 @@ class ALEBO(BotorchModel):
             Xs=self.Xs, Ys=self.Ys, Yvars=self.Yvars, state_dicts=state_dicts
         )
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `X_test` expected.
     @copy_doc(TorchModel.cross_validate)
     def cross_validate(
         self,
