@@ -28,6 +28,7 @@ from ax.models.torch.botorch_moo_defaults import (
     pareto_frontier_evaluator,
     scipy_optimizer_list,
 )
+from ax.models.torch.frontier_utils import TFrontierEvaluator
 from ax.models.torch.utils import (
     _get_X_pending_and_observed,
     _to_inequality_constraints,
@@ -57,18 +58,6 @@ TOptimizerList = Callable[
     ],
     Tuple[Tensor, Tensor],
 ]
-TFrontierEvaluator = Callable[
-    [
-        TorchModel,
-        Tensor,
-        Optional[Tensor],
-        Optional[Tensor],
-        Optional[Tensor],
-        Optional[Tensor],
-        Optional[Tuple[Tensor, Tensor]],
-    ],
-    Optional[Tuple[Tensor, Tensor]],
-]
 
 
 class MultiObjectiveBotorchModel(BotorchModel):
@@ -172,17 +161,17 @@ class MultiObjectiveBotorchModel(BotorchModel):
         frontier_evaluator(
             model,
             objective_weights,
-            ref_point,
+            objective_thresholds,
             X,
             Y,
             Yvar,
             outcome_constraints,
         )
 
-    Here `model` is a botorch `Model`, `ref_point` is used in hypervolume evaluations,
-    `objective_weights` is a tensor of weights applied to the  objectives (sign
-    represents direction), `X`, `Y`, `Yvar` are tensors, `outcome_constraints` is a
-    tuple of tensors describing the (linear) outcome constraints.
+    Here `model` is a botorch `Model`, `objective_thresholds` is used in hypervolume
+    evaluations, `objective_weights` is a tensor of weights applied to the  objectives
+    (sign represents direction), `X`, `Y`, `Yvar` are tensors, `outcome_constraints` is
+    a tuple of tensors describing the (linear) outcome constraints.
     """
 
     dtype: Optional[torch.dtype]
@@ -235,8 +224,6 @@ class MultiObjectiveBotorchModel(BotorchModel):
         self.fidelity_features: List[int] = []
         self.metric_names: List[str] = []
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `bounds` expected.
     @copy_doc(TorchModel.gen)
     def gen(
         self,
@@ -244,13 +231,13 @@ class MultiObjectiveBotorchModel(BotorchModel):
         bounds: List[Tuple[float, float]],
         objective_weights: Tensor,  # objective_directions
         outcome_constraints: Optional[Tuple[Tensor, Tensor]] = None,
+        objective_thresholds: Optional[Tensor] = None,
         linear_constraints: Optional[Tuple[Tensor, Tensor]] = None,
         fixed_features: Optional[Dict[int, float]] = None,
         pending_observations: Optional[List[Tensor]] = None,
         model_gen_options: Optional[TConfig] = None,
         rounding_func: Optional[Callable[[Tensor], Tensor]] = None,
         target_fidelities: Optional[Dict[int, float]] = None,
-        ref_point: Optional[List[float]] = None,
     ) -> Tuple[Tensor, Tensor, TGenMetadata, Optional[List[TCandidateMetadata]]]:
         options = model_gen_options or {}
         acf_options = options.get("acquisition_function_kwargs", {})
@@ -326,14 +313,10 @@ class MultiObjectiveBotorchModel(BotorchModel):
                 **optimizer_options,
             )
         else:
-            if ref_point:
-                ref_point = torch.tensor(
-                    ref_point, dtype=self.dtype, device=self.device
-                )
             acquisition_function = self.acqf_constructor(  # pyre-ignore: [28]
                 model=model,
                 objective_weights=objective_weights,
-                ref_point=ref_point,
+                objective_thresholds=objective_thresholds,
                 outcome_constraints=outcome_constraints,
                 X_observed=X_observed,
                 X_pending=X_pending,
