@@ -26,6 +26,7 @@ from ax.core.types import (
     TParameterization,
     TParamValue,
 )
+from ax.exceptions.constants import CHOLESKY_ERROR_ANNOTATION
 from ax.modelbridge.dispatch_utils import choose_generation_strategy
 from ax.modelbridge.generation_strategy import GenerationStrategy
 from ax.modelbridge.modelbridge_utils import get_pending_observation_features
@@ -61,15 +62,6 @@ from botorch.utils.sampling import manual_seed
 logger = get_logger(__name__)
 
 
-CHOLESKY_ERROR_ANNOTATION = (
-    "Cholesky errors typically occur when the same or very similar "
-    "arms are suggested repeatedly. This can mean the model has "
-    "already converged and you should avoid running further trials. "
-    "It will also help to convert integer or categorical parameters "
-    "to float ranges where reasonable.\nOriginal error: "
-)
-
-
 class AxClient(WithDBSettingsBase):
     """
     Convenience handler for management of experimentation cycle through a
@@ -430,6 +422,13 @@ class AxClient(WithDBSettingsBase):
             trial=trial, raw_data=raw_data, metadata=metadata, sample_sizes=sample_sizes
         )
         trial._run_metadata.update(metadata or {})
+        for metric_name in data.df["metric_name"].values:
+            if metric_name not in self.experiment.metrics:
+                logger.info(
+                    f"Data was logged for metric {metric_name} that was not yet "
+                    "tracked on the experiment. Adding it as tracking metric."
+                )
+                self.experiment.add_tracking_metric(Metric(name=metric_name))
         # Registering trial data update is needed for generation strategies that
         # leverage the `update` functionality of model and bridge setup and therefore
         # need to be aware of new data added to experiment. Usually this happends
@@ -504,17 +503,13 @@ class AxClient(WithDBSettingsBase):
         """Retrieve the parameterization of the trial by the given index."""
         return not_none(self._get_trial(trial_index).arm).parameters
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Expected `Experiment` for 1st param
-    #  but got `(self: AxClient) -> Optional[Tuple[Dict[str, typing.Union[None, bool,
-    #  float, int, str]], Optional[Tuple[Dict[str, float], Optional[Dict[str,
-    #  typing.Dict[str, float]]]]]]]`.
     @copy_doc(best_point_utils.get_best_parameters)
     def get_best_parameters(
         self,
     ) -> Optional[Tuple[TParameterization, Optional[TModelPredictArm]]]:
         return best_point_utils.get_best_parameters(self.experiment)
 
+    # pyre-fixme[11]: Annotation `DataFrame` is not defined as a type.
     def get_trials_data_frame(self) -> pd.DataFrame:
         return exp_to_df(exp=self.experiment)
 
