@@ -149,6 +149,11 @@ class WithDBSettingsBase:
                     f"Generation strategy {generation_strategy.name} is not yet in DB, "
                     "storing it."
                 )
+                # If generation strategy does not yet have an experiment attached,
+                # attach the current experiment to it, as otherwise it will not be
+                # possible to retrieve by experiment name.
+                if generation_strategy._experiment is None:
+                    generation_strategy.experiment = experiment
                 self._save_generation_strategy_to_db_if_possible(
                     generation_strategy=generation_strategy
                 )
@@ -176,11 +181,12 @@ class WithDBSettingsBase:
         if not self.db_settings_set:
             raise ValueError("Cannot load from DB in absence of DB settings.")
 
+        logger.info("Loading experiment and generation strategy...")
         start_time = time.time()
         experiment = _load_experiment(experiment_name, decoder=self.db_settings.decoder)
         if not isinstance(experiment, Experiment) or experiment.is_simple_experiment:
             raise ValueError("Service API only supports `Experiment`.")
-        logger.debug(
+        logger.info(
             f"Loaded experiment {experiment_name} in "
             f"{_round_floats_for_logging(time.time() - start_time)} seconds."
         )
@@ -190,7 +196,7 @@ class WithDBSettingsBase:
             generation_strategy = _load_generation_strategy_by_experiment_name(
                 experiment_name=experiment_name, decoder=self.db_settings.decoder
             )
-            logger.debug(
+            logger.info(
                 f"Loaded generation strategy for experiment {experiment_name} in "
                 f"{_round_floats_for_logging(time.time() - start_time)} seconds."
             )
