@@ -39,10 +39,13 @@ from botorch.models.gp_regression_fidelity import (
     SingleTaskMultiFidelityGP,
 )
 from botorch.models.model import Model
+from botorch.models.model_list_gp_regression import ModelListGP
+from botorch.models.multitask import FixedNoiseMultiTaskGP, MultiTaskGP
 
 # BoTorch `MarginalLogLikelihood` imports
 from gpytorch.mlls.exact_marginal_log_likelihood import ExactMarginalLogLikelihood
 from gpytorch.mlls.marginal_log_likelihood import MarginalLogLikelihood
+from gpytorch.mlls.sum_marginal_log_likelihood import SumMarginalLogLikelihood
 
 
 # NOTE: When adding a new registry for a class, make sure to make changes
@@ -68,6 +71,9 @@ MODEL_REGISTRY: Dict[Type[Model], int] = {
     SingleTaskGP: 1,
     FixedNoiseMultiFidelityGP: 2,
     SingleTaskMultiFidelityGP: 3,
+    ModelListGP: 4,
+    FixedNoiseMultiTaskGP: 5,
+    MultiTaskGP: 6,
 }
 
 
@@ -87,7 +93,10 @@ ACQUISITION_FUNCTION_REGISTRY: Dict[Type[AcquisitionFunction], int] = {
 """
 Mapping of BoTorch `MarginalLogLikelihood` classes to ints.
 """
-MLL_REGISTRY: Dict[Type[MarginalLogLikelihood], int] = {ExactMarginalLogLikelihood: 0}
+MLL_REGISTRY: Dict[Type[MarginalLogLikelihood], int] = {
+    ExactMarginalLogLikelihood: 0,
+    SumMarginalLogLikelihood: 1,
+}
 
 
 """
@@ -133,3 +142,11 @@ CLASS_TO_REVERSE_REGISTRY: Dict[Any, Dict[int, Type[Any]]] = {
     MarginalLogLikelihood: REVERSE_MLL_REGISTRY,
     Model: REVERSE_MODEL_REGISTRY,
 }
+
+
+def register_acquisition(acq_class: Type[Acquisition]) -> None:
+    """Add a custom acquisition class to the SQA and JSON registries."""
+    ACQUISITION_REGISTRY = CLASS_TO_REGISTRY[Acquisition]
+    index = len(ACQUISITION_REGISTRY)
+    CLASS_TO_REGISTRY[Acquisition].update({acq_class: index})
+    CLASS_TO_REVERSE_REGISTRY[Acquisition].update({index: acq_class})
