@@ -16,8 +16,11 @@ from ax.core.generator_run import GeneratorRun, GeneratorRunType
 from ax.core.metric import Metric
 from ax.core.multi_type_experiment import MultiTypeExperiment
 from ax.core.objective import MultiObjective, Objective, ScalarizedObjective
-from ax.core.optimization_config import OptimizationConfig
-from ax.core.outcome_constraint import OutcomeConstraint
+from ax.core.optimization_config import (
+    MultiObjectiveOptimizationConfig,
+    OptimizationConfig,
+)
+from ax.core.outcome_constraint import ObjectiveThreshold, OutcomeConstraint
 from ax.core.parameter import ChoiceParameter, FixedParameter, Parameter, RangeParameter
 from ax.core.parameter_constraint import (
     OrderConstraint,
@@ -33,6 +36,7 @@ from ax.modelbridge.generation_strategy import GenerationStrategy
 from ax.storage.json_store.encoder import object_to_json
 from ax.storage.metric_registry import METRIC_REGISTRY
 from ax.storage.runner_registry import RUNNER_REGISTRY
+from ax.storage.sqa_store.db import SQABase
 from ax.storage.sqa_store.sqa_classes import (
     SQAAbandonedArm,
     SQAArm,
@@ -48,13 +52,14 @@ from ax.storage.sqa_store.sqa_classes import (
 )
 from ax.storage.sqa_store.sqa_config import SQAConfig
 from ax.storage.utils import DomainType, MetricIntent, ParameterConstraintType
+from ax.utils.common.base import Base
 from ax.utils.common.constants import Keys
-from ax.utils.common.equality import Base, datetime_equals
+from ax.utils.common.equality import datetime_equals
 from ax.utils.common.logger import get_logger
-from ax.utils.common.typeutils import not_none
 
 
 logger = get_logger(__name__)
+T_OBJ_TO_SQA = List[Tuple[Base, SQABase]]
 
 
 class Encoder:
@@ -117,9 +122,7 @@ class Encoder:
         )
         tracking_metrics = [
             self.metric_to_sqa(metric)
-            for metric in experiment.metrics.values()
-            if experiment.optimization_config is None
-            or metric.name not in not_none(experiment.optimization_config).metrics
+            for metric in experiment._tracking_metrics.values()
         ]
         parameters, parameter_constraints = self.search_space_to_sqa(
             experiment.search_space
@@ -485,6 +488,27 @@ class Encoder:
             lower_is_better=metric.lower_is_better,
         )
 
+    def objective_threshold_to_sqa(
+        self, objective_threshold: ObjectiveThreshold
+    ) -> SQAMetric:
+        """Convert Ax OutcomeConstraint to SQLAlchemy."""
+        metric = objective_threshold.metric
+        metric_type, properties = self.get_metric_type_and_properties(metric=metric)
+
+        # pyre-fixme: Expected `Base` for 1st...t `typing.Type[Metric]`.
+        metric_class: SQAMetric = self.config.class_to_sqa_class[Metric]
+        # pyre-fixme[29]: `SQAMetric` is not a function.
+        return metric_class(
+            name=metric.name,
+            metric_type=metric_type,
+            intent=MetricIntent.OBJECTIVE_THRESHOLD,
+            bound=objective_threshold.bound,
+            op=objective_threshold.op,
+            relative=objective_threshold.relative,
+            properties=properties,
+            lower_is_better=metric.lower_is_better,
+        )
+
     def optimization_config_to_sqa(
         self, optimization_config: Optional[OptimizationConfig]
     ) -> List[SQAMetric]:
@@ -497,7 +521,14 @@ class Encoder:
             self.outcome_constraint_to_sqa(outcome_constraint=constraint)
             for constraint in optimization_config.outcome_constraints
         ]
-        return [objective_sqa] + outcome_constraints_sqa
+        if isinstance(optimization_config, MultiObjectiveOptimizationConfig):
+            objective_thresholds_sqa = [
+                self.objective_threshold_to_sqa(objective_threshold=threshold)
+                for threshold in optimization_config.objective_thresholds
+            ]
+        else:
+            objective_thresholds_sqa = []
+        return [objective_sqa] + outcome_constraints_sqa + objective_thresholds_sqa
 
     def arm_to_sqa(self, arm: Arm, weight: Optional[float] = 1.0) -> SQAArm:
         """Convert Ax Arm to SQLAlchemy."""
