@@ -5,6 +5,8 @@
 # LICENSE file in the root directory of this source tree.
 
 from datetime import datetime
+from inspect import signature
+from typing import Callable
 from unittest.mock import MagicMock, Mock
 
 from ax.core.arm import Arm
@@ -34,7 +36,7 @@ from ax.storage.sqa_store.db import (
     session_scope,
 )
 from ax.storage.sqa_store.decoder import Decoder
-from ax.storage.sqa_store.encoder import Encoder
+from ax.storage.sqa_store.encoder import T_OBJ_TO_SQA, Encoder
 from ax.storage.sqa_store.load import (
     load_experiment,
     load_generation_strategy_by_experiment_name,
@@ -82,8 +84,10 @@ from ax.utils.testing.core_stubs import (
     get_experiment_with_scalarized_objective,
     get_fixed_parameter,
     get_generator_run,
+    get_multi_objective_optimization_config,
     get_multi_type_experiment,
     get_objective,
+    get_objective_threshold,
     get_optimization_config,
     get_outcome_constraint,
     get_range_parameter,
@@ -95,6 +99,19 @@ from ax.utils.testing.core_stubs import (
 from ax.utils.testing.modeling_stubs import get_generation_strategy
 
 
+def _encode_func_returns_obj_to_sqa(encode_func: Callable) -> bool:
+    """Some encoding functions return both the encoded object and `obj_to_sqa`,
+    with the latter being a list of tuples of form (obj, sqa_obj), used to
+    set `db_id` on Ax objects after they are saved. This function checks
+    return type of `encode_func` to determine whether `encode_func` is one
+    of such functions.
+    """
+    encode_func_return_type = signature(encode_func).return_annotation
+    return (getattr(encode_func_return_type, "_name", "") == "Tuple") and (
+        T_OBJ_TO_SQA in getattr(encode_func_return_type, "__args__", ())
+    )
+
+
 class SQAStoreTest(TestCase):
     def setUp(self):
         init_test_engine_and_session_factory(force_init=True)
@@ -301,6 +318,10 @@ class SQAStoreTest(TestCase):
             encode_func = unbound_encode_func.__get__(self.encoder)
             decode_func = unbound_decode_func.__get__(self.decoder)
             sqa_object = encode_func(original_object)
+            if _encode_func_returns_obj_to_sqa(encode_func=encode_func):
+                # Some encoding functions returns two things, of which for
+                # encoding we only care about the first.
+                sqa_object = sqa_object[0]
 
             if class_ in ["OrderConstraint", "ParameterConstraint", "SumConstraint"]:
                 converted_object = decode_func(sqa_object, self.dummy_parameters)
@@ -340,6 +361,10 @@ class SQAStoreTest(TestCase):
 
             encode_func = unbound_encode_func.__get__(self.encoder)
             sqa_object = encode_func(original_object)
+            if _encode_func_returns_obj_to_sqa(encode_func=encode_func):
+                # Some encoding functions returns two things, of which for
+                # encoding we only care about the first.
+                sqa_object = sqa_object[0]
 
             if isinstance(
                 original_object, AbandonedArm
@@ -559,6 +584,53 @@ class SQAStoreTest(TestCase):
         loaded_experiment = load_experiment(experiment.name)
         self.assertEqual(experiment, loaded_experiment)
 
+    def testExperimentObjectiveThresholdUpdates(self):
+        experiment = get_experiment_with_batch_trial()
+        save_experiment(experiment)
+        self.assertEqual(
+            get_session().query(SQAMetric).count(), len(experiment.metrics)
+        )
+
+        # update objective threshold
+        # (should perform update in place)
+        optimization_config = get_multi_objective_optimization_config()
+        objective_threshold = get_objective_threshold()
+        optimization_config.objective_thresholds = [objective_threshold]
+        experiment.optimization_config = optimization_config
+        save_experiment(experiment)
+        self.assertEqual(get_session().query(SQAMetric).count(), 6)
+
+        # add outcome constraint
+        outcome_constraint2 = OutcomeConstraint(
+            metric=Metric(name="outcome"), op=ComparisonOp.GEQ, bound=-0.5
+        )
+        optimization_config.outcome_constraints = [
+            optimization_config.outcome_constraints[0],
+            outcome_constraint2,
+        ]
+        experiment.optimization_config = optimization_config
+        save_experiment(experiment)
+        self.assertEqual(get_session().query(SQAMetric).count(), 7)
+
+        # remove outcome constraint
+        # (old one should become tracking metric)
+        optimization_config.outcome_constraints = []
+        experiment.optimization_config = optimization_config
+        save_experiment(experiment)
+        self.assertEqual(get_session().query(SQAMetric).count(), 5)
+
+        loaded_experiment = load_experiment(experiment.name)
+        self.assertEqual(experiment, loaded_experiment)
+
+        # Optimization config should correctly reload even with no
+        # objective_thresholds
+        optimization_config.objective_thresholds = []
+        save_experiment(experiment)
+        self.assertEqual(get_session().query(SQAMetric).count(), 4)
+
+        loaded_experiment = load_experiment(experiment.name)
+        self.assertEqual(experiment, loaded_experiment)
+
     def testFailedLoad(self):
         with self.assertRaises(ValueError):
             load_experiment("nonexistent_experiment")
@@ -938,7 +1010,9 @@ class SQAStoreTest(TestCase):
 
         # Check that we can encode and decode the generation strategy *after*
         # it has generated some trials and been updated with some data.
-        generation_strategy = new_generation_strategy
+        # Since we now need to `gen`, we remove the fake callable kwarg we added,
+        # since model does not expect it.
+        generation_strategy = get_generation_strategy(with_callable_model_kwarg=False)
         experiment.new_trial(generation_strategy.gen(experiment=experiment))
         generation_strategy.gen(experiment, data=get_branin_data())
         save_generation_strategy(generation_strategy=generation_strategy)
@@ -955,11 +1029,10 @@ class SQAStoreTest(TestCase):
         self.assertEqual(new_generation_strategy._experiment._name, experiment._name)
 
     def testUpdateGenerationStrategy(self):
-        generation_strategy = get_generation_strategy()
+        generation_strategy = get_generation_strategy(with_callable_model_kwarg=False)
         save_generation_strategy(generation_strategy=generation_strategy)
 
         experiment = get_branin_experiment()
-        generation_strategy = get_generation_strategy()
         save_experiment(experiment)
 
         # add generator run, save, reload
