@@ -28,16 +28,6 @@ def equality_typechecker(eq_func: Callable) -> Callable:
     return _type_safe_equals
 
 
-class Base(object):
-    """Metaclass for core Ax classes."""
-
-    @equality_typechecker
-    def __eq__(self, other: Base) -> bool:
-        return object_attribute_dicts_equal(
-            one_dict=self.__dict__, other_dict=other.__dict__
-        )
-
-
 def same_elements(list1: List[Any], list2: List[Any]) -> bool:
     """Compare equality of two lists of core Ax objects.
 
@@ -81,12 +71,14 @@ def datetime_equals(dt1: Optional[datetime], dt2: Optional[datetime]) -> bool:
     return dt1.replace(microsecond=0) == dt2.replace(microsecond=0)
 
 
+# pyre-fixme[11]: Annotation `DataFrame` is not defined as a type.
 def dataframe_equals(df1: pd.DataFrame, df2: pd.DataFrame) -> bool:
     """Compare equality of two pandas dataframes."""
     try:
         if df1.empty and df2.empty:
             equal = True
         else:
+            # pyre-fixme[16]: Module `pd` has no attribute `testing`.
             pd.testing.assert_frame_equal(
                 df1.sort_index(axis=1), df2.sort_index(axis=1), check_exact=False
             )
@@ -169,6 +161,7 @@ def object_attribute_dicts_find_unequal_fields(
             equal = datetime_equals(one_val, other_val)
         elif isinstance(one_val, float):
             equal = np.isclose(one_val, other_val)
+        # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
         elif isinstance(one_val, pd.DataFrame):
             equal = dataframe_equals(one_val, other_val)
         else:
