@@ -4,8 +4,9 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from datetime import datetime
+from datetime import datetime, timedelta
 from time import time
+from typing import Generator
 
 import pandas as pd
 
@@ -25,6 +26,7 @@ def to_ts(ds: str) -> datetime:
 
 def _ts_to_pandas(ts: int) -> pd.Timestamp:  # pyre-ignore[11]
     """Convert int timestamp into pandas timestamp."""
+    # pyre-fixme[16]: Module `pd` has no attribute `Timestamp`.
     return pd.Timestamp(datetime.fromtimestamp(ts))
 
 
@@ -36,3 +38,15 @@ def _pandas_ts_to_int(ts: pd.Timestamp) -> int:
 def current_timestamp_in_millis() -> int:
     """Grab current timestamp in milliseconds as an int."""
     return int(round(time() * 1000))
+
+
+def timestamps_in_range(
+    start: datetime, end: datetime, delta: timedelta
+) -> Generator[datetime, None, None]:
+    """Generator of timestamps in range [start, end], at intervals
+    delta.
+    """
+    curr = start
+    while curr <= end:
+        yield curr
+        curr += delta
