@@ -20,8 +20,11 @@ from ax.core.generator_run import GeneratorRun
 from ax.core.metric import Metric
 from ax.core.multi_type_experiment import MultiTypeExperiment
 from ax.core.objective import MultiObjective, Objective, ScalarizedObjective
-from ax.core.optimization_config import OptimizationConfig
-from ax.core.outcome_constraint import OutcomeConstraint
+from ax.core.optimization_config import (
+    MultiObjectiveOptimizationConfig,
+    OptimizationConfig,
+)
+from ax.core.outcome_constraint import ObjectiveThreshold, OutcomeConstraint
 from ax.core.parameter import (
     ChoiceParameter,
     FixedParameter,
@@ -51,6 +54,7 @@ from ax.metrics.hartmann6 import AugmentedHartmann6Metric, Hartmann6Metric
 from ax.modelbridge.factory import Cont_X_trans, get_factorial, get_sobol
 from ax.models.torch.botorch_modular.acquisition import Acquisition
 from ax.models.torch.botorch_modular.kg import KnowledgeGradient
+from ax.models.torch.botorch_modular.list_surrogate import ListSurrogate
 from ax.models.torch.botorch_modular.model import BoTorchModel
 from ax.models.torch.botorch_modular.surrogate import Surrogate
 from ax.runners.synthetic import SyntheticRunner
@@ -242,11 +246,7 @@ def get_experiment_with_data() -> Experiment:
 
 
 def get_experiment_with_multi_objective() -> Experiment:
-    objective = get_multi_objective()
-    outcome_constraints = [get_outcome_constraint()]
-    optimization_config = OptimizationConfig(
-        objective=objective, outcome_constraints=outcome_constraints
-    )
+    optimization_config = get_multi_objective_optimization_config()
 
     exp = Experiment(
         name="test_experiment_multi_objective",
@@ -471,7 +471,7 @@ def get_batch_trial(abandon_arm: bool = True) -> BatchTrial:
 
 
 def get_batch_trial_with_repeated_arms(num_repeated_arms: int) -> BatchTrial:
-    """ Create a batch that contains both new arms and N arms from the last
+    """Create a batch that contains both new arms and N arms from the last
     existed trial in the experiment. Where N is equal to the input argument
     'num_repeated_arms'.
     """
@@ -638,6 +638,12 @@ def get_factorial_metric(name: str = "success_metric") -> FactorialMetric:
 ##############################
 
 
+def get_objective_threshold() -> ObjectiveThreshold:
+    return ObjectiveThreshold(
+        metric=Metric(name="m1"), bound=-0.25, op=ComparisonOp.GEQ
+    )
+
+
 def get_outcome_constraint() -> OutcomeConstraint:
     return OutcomeConstraint(metric=Metric(name="m2"), op=ComparisonOp.GEQ, bound=-0.25)
 
@@ -709,6 +715,17 @@ def get_optimization_config() -> OptimizationConfig:
     )
 
 
+def get_multi_objective_optimization_config() -> OptimizationConfig:
+    objective = get_multi_objective()
+    outcome_constraints = [get_outcome_constraint()]
+    objective_thresholds = [get_objective_threshold()]
+    return MultiObjectiveOptimizationConfig(
+        objective=objective,
+        outcome_constraints=outcome_constraints,
+        objective_thresholds=objective_thresholds,
+    )
+
+
 def get_optimization_config_no_constraints() -> OptimizationConfig:
     return OptimizationConfig(objective=Objective(metric=Metric("test_metric")))
 
@@ -718,7 +735,7 @@ def get_branin_optimization_config() -> OptimizationConfig:
 
 
 def get_branin_multi_objective_optimization_config() -> OptimizationConfig:
-    return OptimizationConfig(objective=get_branin_multi_objective())
+    return MultiObjectiveOptimizationConfig(objective=get_branin_multi_objective())
 
 
 def get_augmented_branin_optimization_config() -> OptimizationConfig:
@@ -867,6 +884,7 @@ def get_data(trial_index: int = 0) -> Data:
         "sem": [0, 0.5, 0.25, 0.40, 0.15],
         "n": [100, 100, 100, 100, 100],
     }
+    # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
     return Data(df=pd.DataFrame.from_records(df_dict))
 
 
@@ -881,11 +899,13 @@ def get_branin_data(trial_indices: Optional[Iterable[int]] = None) -> Data:
         }
         for trial_index in (trial_indices or [0])
     ]
+    # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
     return Data(df=pd.DataFrame.from_records(df_dicts))
 
 
 def get_branin_data_batch(batch: BatchTrial) -> Data:
     return Data(
+        # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
         pd.DataFrame(
             {
                 "arm_name": [arm.name for arm in batch.arms],
@@ -916,6 +936,7 @@ def get_branin_data_multi_objective(
         for trial_index in (trial_indices or [0])
         for suffix in ["a", "b"]
     ]
+    # pyre-fixme[16]: Module `pd` has no attribute `DataFrame`.
     return Data(df=pd.DataFrame.from_records(df_dicts))
 
 
@@ -980,7 +1001,20 @@ def get_botorch_model_with_default_acquisition_class() -> BoTorchModel:
 
 
 def get_surrogate() -> Surrogate:
-    return Surrogate(get_model_type())
+    return Surrogate(
+        botorch_model_class=get_model_type(),
+        mll_class=get_mll_type(),
+        model_options={"some_option": "some_value"},
+    )
+
+
+def get_list_surrogate() -> Surrogate:
+    return ListSurrogate(
+        botorch_submodel_class_per_outcome={"m": get_model_type()},
+        submodel_options_per_outcome={"m": {"some_option": "some_value"}},
+        submodel_options={"shared_option": "shared_option_value"},
+        mll_class=get_mll_type(),
+    )
 
 
 def get_acquisition_type() -> Type[Acquisition]:
